==> apache-trafficcontrol-5.1.6.tar.gz: apache-trafficcontrol-5.1.6/traffic_portal/app/src/modules/private/serverCapabilities/deliveryServices/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.serverCapabilities.deliveryServices', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.serverCapabilities.deliveryServices', {
				url: '/{serverCapability}/delivery-services',
				views: {
					serverCapabilitiesContent: {
						templateUrl: 'common/modules/table/serverCapabilityDeliveryServices/table.serverCapabilityDeliveryServices.tpl.html',
						controller: 'TableServerCapabilityDeliveryServicesController',
						resolve: {
							serverCapability: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapability($stateParams.serverCapability);
							},
							deliveryServices: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapabilityDeliveryServices($stateParams.serverCapability);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_portal/app/src/modules/private/serverCapabilities/deliveryServices/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.serverCapabilities.deliveryServices', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.serverCapabilities.deliveryServices', {
				url: '/delivery-services?name',
				views: {
					serverCapabilitiesContent: {
						templateUrl: 'common/modules/table/serverCapabilityDeliveryServices/table.serverCapabilityDeliveryServices.tpl.html',
						controller: 'TableServerCapabilityDeliveryServicesController',
						resolve: {
							serverCapability: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapability($stateParams.name);
							},
							deliveryServices: function($stateParams, serverCapabilityService) {
								return serverCapabilityService.getServerCapabilityDeliveryServices($stateParams.name);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
